#
# spec file for package nim
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _atlas_version 0.8.0
%define _sat_commit faf1617f44d7632ee9601ebc13887644925dcc01

Name:           nim
Version:        2.0.14
Release:        1.1
Summary:        A statically typed compiled systems programming language
License:        MIT
Group:          Development/Languages/Other
URL:            https://nim-lang.org/
Source0:        https://nim-lang.org/download/nim-%{version}.tar.xz
Source1:        https://github.com/nim-lang/atlas/archive/refs/tags/%{_atlas_version}.tar.gz#/atlas-%{_atlas_version}.tar.gz
Source2:        nim-rpmlintrc
Source3:        https://github.com/nim-lang/sat/archive/%{_sat_commit}.tar.gz#/sat-%{_sat_commit}.tar.gz
Patch0:         nim-nim-gdb_fix_interpreter.patch
Patch1:         nim-fix-tests-i586.patch
Patch2:         0001-disable-toop1-test.patch
Patch3:         0002-disable-tvmmisc-test.patch
Patch4:         0003-disable-cpp-tmanual_exception-test.patch
Patch5:         0004-disable-tobjcov-test.patch
BuildRequires:  binutils-devel
BuildRequires:  ca-certificates
BuildRequires:  ca-certificates-mozilla
# required for the testsuite
BuildRequires:  gc-devel
# Nim needs support for both __builtin_saddll_overflow and
# -std=c++14, therefore gcc 6.2+ is required.
BuildRequires:  gcc-c++ >= 6.2
BuildRequires:  git
BuildRequires:  libopenssl-devel
BuildRequires:  netcfg libnss_usrfiles2
BuildRequires:  pcre
BuildRequires:  sqlite3-devel
BuildRequires:  timezone
BuildRequires:  valgrind
# pull in a C compiler (required to build Nim programs)
Requires:       gcc
Recommends:     clang
Recommends:     git
Recommends:     pcre
ExclusiveArch:  %{ix86} x86_64 armv7l armv7hl aarch64 ppc64le riscv64
# Needs node 12 for flag --unhandled-rejections=strict, but it's not
# strictly needed (it's used to test the Nim JS compiler, so we can
# skip it and run tests without this compiler target afterwards)
%if 0%{?suse_version} >= 1501 || (0%{?suse_version} >= 1501 && 0%{?is_backports})
BuildRequires:  nodejs >= 12
Recommends:     nodejs
%endif

%description
Nim is a statically typed compiled systems programming language. It
combines successful concepts from mature languages like Python, Ada
and Modula.

Efficient:
* Nim generates native dependency-free executables, not dependent on
  a virtual machine, which are small and allow easy redistribution.
* The Nim compiler and the generated executables support all major
  platforms like Windows, Linux, BSD and macOS.
* Nim's memory management is deterministic and customizable with
  destructors and move semantics, inspired by C++ and Rust. It is
  well-suited for embedded, hard-realtime systems.
* Modern concepts like zero-overhead iterators and compile-time
  evaluation of user-defined functions, in combination with the
  preference of value-based datatypes allocated on the stack, lead
  to extremely performant code.
* Support for various backends: it compiles to C, C++ or JavaScript
  so that Nim can be used for all backend and frontend needs.

Expressive:
* Nim is self-contained: the compiler and the standard library are
  implemented in Nim.
* Nim has a powerful macro system which allows direct manipulation
  of the AST, offering nearly unlimited opportunities.

Elegant:
* Macros cannot change Nim's syntax because there is no need for it
  — the syntax is flexible enough.
* Modern type system with local type inference, tuples, generics and
  sum types.
* Statements are grouped by indentation but can span multiple lines.

%prep
%setup -a1 -a3

mv atlas-%{_atlas_version} dist/atlas
mkdir dist/atlas/dist
mv sat-%{_sat_commit} dist/atlas/dist/sat

%patch -P 0 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1
%ifarch i586
%patch -P 1 -p1
%endif

%build
export CFLAGS="%{optflags}"
export NIMFLAGS="$(echo '%{optflags}' | sed 's/\([^[:space:]]\+\)/--passC:\1/g')"
export NIMFLAGS="$NIMFLAGS %{?jobs:--parallelBuild:%{jobs}}"

./build.sh
# %make_build CFLAGS="%{optflags}"

./bin/nim c  $NIMFLAGS -d:release koch
./koch boot  $NIMFLAGS -d:release
./koch tools $NIMFLAGS -d:release

# TODO: build docs
# ./koch docs

%check

cat << EOT >> tests_to_skip
  # we don't care about testament itself
  tests/testament/tjoinable.nim
  tests/testament/tshould_not_work.nim
  # cannot open file: zip/zipfiles
  tests/manyloc/nake/nakefile.nim
  # cannot open file: zip/zlib
  tests/manyloc/keineschweine/keineschweine.nim
  # Temporary failure in name resolution (tries to use netcode)
  tests/stdlib/thttpclient.nim
  tests/stdlib/tnetconnect.nim
  # client: exception: error:1416F086:SSL routines:tls_process_server_certificate:certificate verify failed
  tests/stdlib/thttpclient_ssl.nim
  # cannot open file: jester
  tests/niminaction/Chapter7/Tweeter/src/tweeter.nim
  tests/cpp/tasync_cpp.nim
  # # only working with megatest enabled
  # tests/misc/tjoinable.nim
  # expects Nim to be in PATH...
  tests/stdlib/tosproc.nim
  # following tests are flaky
  tests/stdlib/tio.nim
  tests/arc/thard_alignment.nim
  # this one needs NodeJS althought its not required by the build
  tests/nimdoc/trunnableexamples.nim
  tests/js/tnativeexc.nim
  # broken in Leap 15.3
  tests/exception/t13115.nim
  # no SFML in plain SLE and missing in backport repos
  tests/niminaction/Chapter8/sfml/sfml_test.nim
EOT

%ifarch i586
cat << EOT >> tests_to_skip
  # flaky test, fails in i586
  tests/async/tasyncssl.nim
  tests/realtimeGC/tmain.nim
  tests/realtimeGC/shared.nim
  tests/stdlib/tcasts.nim
EOT
%endif

%ifarch aarch64 armv7l armv7hl ppc64le riscv64
cat << EOT >> tests_to_skip
  # fails because it includes immintrin.h
  tests/misc/tsizeof4.nim

  # armv7l
  tests/stdlib/tarithmetics.nim
  tests/vm/tslow_tables.nim
  tests/tuples/t12892.nim
  tests/dll/nimhcr_unit.nim
  tests/arc/tcaseobj.nim
  tests/arc/tcaseobjcopy.nim
  tests/async/tasyncssl.nim

  #aarch64 and ppc64l
  tests/range/tcompiletime_range_checks.nim
  tests/dll/nimhcr_unit.nim

  #ppc64le
  tests/arc/tasyncorc.nim
EOT
%endif

%if 0%{?suse_version} < 1501
cat << EOT >> tests_to_skip
  # deactivate all tests that require node, as node version in
  # SLE and Leap 15.1 is either too old or not available at all
  tests/misc/trunner.nim
EOT
%endif

%if 0%{?qemu_user_space_build}
cat << EOT >> tests_to_skip
  # valgrind is not compatible with QEMU user-space emulation,
  # skip all test using it
  tests/views/tsplit_into_openarray.nim
  tests/destructor/tnewruntime_strutils.nim
  tests/destructor/tv2_raise.nim
  tests/valgrind/tleak_arc.nim
  tests/valgrind/tbasic_valgrind.nim
  tests/arc/tunref_cycle.nim
  tests/arc/tcustomtrace.nim
  tests/arc/tcaseobj.nim
  tests/arc/t14472.nim
  tests/arc/tasyncleak4.nim
  tests/arc/thavlak_orc_stress.nim
  tests/arc/torc_selfcycles.nim
  tests/arc/tfuncobj.nim
  tests/arc/tasyncleak3.nim
  tests/arc/tasyncorc.nim
  tests/arc/tcaseobjcopy.nim
EOT
%endif

# Tests as many targets as possible
NIM_COMPILER_TARGETS="c"
if rpm -q --whatprovides c++_compiler; then
    NIM_COMPILER_TARGETS="$NIM_COMPILER_TARGETS c++"
fi
if rpm -q --whatprovides nodejs; then
    NIM_COMPILER_TARGETS="$NIM_COMPILER_TARGETS js"
fi

./koch tests \
  --nim:$PWD/bin/nim \
  --failing \
  --colors:off \
  --megatest:on \
  --skipFrom:tests_to_skip \
  --targets:"$NIM_COMPILER_TARGETS" \
  all

%install
# extract everything into a staging location, as Nim devels like to
# add/remove things in an unusual way and we want to find out what
# is added/removed/modified on future versions to avoid errors
# while packaging it
TARGET="%{buildroot}/_pending"

./koch install $TARGET

# some binaries aren't installed at target location by koch
cp ./bin/* $TARGET/nim/bin/

mkdir -p \
  %{buildroot}%{_bindir}/ \
  %{buildroot}%{_libdir}/nim \
  %{buildroot}%{_sysconfdir}/nim \
  %{buildroot}%{_docdir}/nim

# remove things that aren't needed
rm $TARGET/nim/lib/pure/unidecode/gen.py

# fix endlines
sed -i 's/\r$//' $TARGET/nim/doc/nimdoc.css

# move executables to final location (or delete what isn't needed)
rm $TARGET/nim/bin/atlas
rm $TARGET/nim/bin/testament
rm $TARGET/nim/nim.nimble
mv $TARGET/nim/bin %{buildroot}%{_libdir}/nim/

# strip all symbols from binaries
strip --strip-all %{buildroot}%{_libdir}/nim/bin/nim
strip --strip-all %{buildroot}%{_libdir}/nim/bin/nimble
strip --strip-all %{buildroot}%{_libdir}/nim/bin/nim_dbg
strip --strip-all %{buildroot}%{_libdir}/nim/bin/nimgrep
strip --strip-all %{buildroot}%{_libdir}/nim/bin/nimpretty
strip --strip-all %{buildroot}%{_libdir}/nim/bin/nimsuggest

# nim requires symlinks to executables, as it looks for its
# standard library by resolving the link and then checking for
# parent paths, which is quite unusual...
ln -s %{_libdir}/nim/bin/nim        %{buildroot}%{_bindir}
ln -s %{_libdir}/nim/bin/nim-gdb    %{buildroot}%{_bindir}
ln -s %{_libdir}/nim/bin/nim_dbg    %{buildroot}%{_bindir}
ln -s %{_libdir}/nim/bin/nimble     %{buildroot}%{_bindir}
ln -s %{_libdir}/nim/bin/nimgrep    %{buildroot}%{_bindir}
ln -s %{_libdir}/nim/bin/nimpretty  %{buildroot}%{_bindir}
ln -s %{_libdir}/nim/bin/nimsuggest %{buildroot}%{_bindir}

mv $TARGET/nim/compiler* %{buildroot}%{_libdir}/nim/
mv $TARGET/nim/lib       %{buildroot}%{_libdir}/nim/
mv $TARGET/nim/doc       %{buildroot}%{_docdir}/nim/
mv $TARGET/nim/config/*  %{buildroot}%{_sysconfdir}/nim/

%files

%license copying.txt
%doc %{_docdir}/nim

%{_bindir}/nim
%{_bindir}/nim-gdb
%{_bindir}/nim_dbg
%{_bindir}/nimble
%{_bindir}/nimgrep
%{_bindir}/nimpretty
%{_bindir}/nimsuggest

%dir %{_sysconfdir}/nim
%config %{_sysconfdir}/nim/*

%{_libdir}/nim/

%changelog
* Tue Jan 21 2025 Rein Fernhout <me@levitati.ng>
- Update to version 2.0.14
  See https://nim-lang.org/blog/2024/12/24/nim-2014-released.html
* Thu Dec 12 2024 Rein Fernhout <me@levitati.ng>
- Added various patches to disable tests that
  don't pass on the current version of GCC.
  * 0001-disable-toop1-test.patch
  * 0002-disable-tvmmisc-test.patch
  * 0003-disable-cpp-tmanual_exception-test.patch
  * 0004-disable-tobjcov-test.patch
* Thu Dec 12 2024 Rein Fernhout <me@levitati.ng>
- Update to version 2.0.12
  See https://nim-lang.org/blog/2024/11/01/nim-2012-released.html
  and https://nim-lang.org/blog/2024/10/02/nim-220-2010.html
  and https://nim-lang.org/blog/2024/07/03/version-208-released.html
  for all changes.
* Tue Jun 18 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 2.0.6:
  * over 80 bugfixes, complete list available at https://nim-lang.org/blog/2024/06/17/version-206-released.html
- dropped patch nim-fix-build-with-gcc14.patch as already included in upstream
* Wed Jun 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N to apply patches. This works with all current RPM
  versions in use and means we don't have to maintain two blocks to
  apply patches.
* Wed May 29 2024 David Anes <david.anes@suse.com>
- Fix build with gcc14+:
  * Add nim-fix-build-with-gcc14.patch
* Thu May 23 2024 David Anes <david.anes@suse.com>
- Disable broken test for i586:
  * Add nim-fix-tests-i586.patch
* Wed Apr 17 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 2.0.4:
  * Fixed “import sth from mymodule is compiles and trying to see module sthfrommymodule” (#23148)
  * Fixed “Operations on inline toOpenArray len return a wrong result” (#23280)
  * Fixed “Nimsuggest segfault with invalid assignment to table” (#22753)
  The complete list of changes is available here: https://github.com/nim-lang/Nim/compare/v2.0.2...v2.0.4
- Updated atlas tarball to 0.8.0
* Wed Dec 20 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 2.0.2:
  * Fixed “Undefined behavior when with hash(...) on non-aligned bytes due to murmurHash cast[ptr int32]” (#22387)
  * Fixed “async/closure environment does not align local variables” (#22419)
  * Fixed “Debugging/stepping is broken in 2.0.0 and 2.1.1” (#22366)
  * Fixed “when picks wrong branch with static int” (#22474)
  * Fixed “Regression from 1.6.14 to 2.0.0 - nimble test crashes with a core dump” (#22357)
  * Fixed “Long-term arc-closure iterator problem” (#22619)
  * Fixed “-d:useMalloc broken with --mm:none and threads on” (#22262)
  * Fixed “Crash of compiler on array type check” (#5780)
  * Fixed “Undefined behaviorwith set card() on non-aligned pointer from cardSetImpl/countBits64cast on ptr uint64” (#22481)
  * Fixed “elementType from std/typetraits doesn’t work in generic procs” (#21532)
  * Fixed “peg matchLen can raise an unlisted exception: Exception” (#22541)
  * Fixed “Piece of code output c compiler error “ (#17197)
  * Fixed “Missing type inference in loop + case + if + continue” (#22604)
  * Fixed “Invalid type mismatch in generic” (#17509)
  * Fixed “std/nativesockets getHostByAddr should support IPv6” (#22834)
  * Fixed “std/nre leaks memory on every created Regex due to auto-translated finalizers behaving differently under ARC/ORC” (#22868)
  * Fixed “Destructor not called for temp objects passed as arguments” (#22866)
  * Fixed “nimsuggest inlay hints for types shown in the wrong place for exported vars and consts” (#23067)
  * Fixed “[Regression] static integers in quote do” (#22947)
* Sat Aug  5 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove move of $TARGET/tools since it does not exist.
* Sat Aug  5 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove move of `nim-gdb.py` since it's in ./tools/debug/ now.
* Sat Aug  5 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add atlas version 0.6.2 tarball. It will be extracted to dist/atlas directory from the
  root of the project.
* Sat Aug  5 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 2.0.0:
  * better tuple unpacking
  * forbidden tags
  * improved type inference
  * new standard library modules:
  - std/oserrors
  - std/envvars
  - std/dirs
  - std/files
  - std/symlinks
  - std/appdirs
  - std/cmdline
  * overloadable enums
  * default value for objects
  * definite assignment analysis
  * strict effects
  * improved error message for type mismatch
  * consistent underscore handling
  * javascript codegen improvement
  * docgen improvements
  * c++ interop enhancements
  * ARC/ORC refinements
  * using an unnamed break in a block is deprecated
  * new strict funcs definition
  * several standard library modules are now moved to nimble packagse
  - std/punycode => punycode
  - std/asyncftpclient => asyncftpclient
  - std/smtp => smtp
  - std/db_common => db_connector/db_common
  - std/db_sqlite => db_connector/db_sqlite
  - std/db_mysql => db_connector/db_mysql
  - std/db_postgres => db_connector/db_postgres
  - std/db_odbc => db_connector/db_odbc
  - std/md5 => checksums/md5
  - std/sha1 => checksums/sha1
  - std/sums => sums
- remove nim-fix-tests-ip-protocol-missing.patch
* Wed Jul  5 2023 Andreas Schwab <schwab@suse.de>
- Enable build on riscv64
- Skip all tests using valgrind when running under QEmu user-space emulation
* Wed Jun 28 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.6.14:
  * more than 179 commits providing bugfixes and general improvements,
    details at https://github.com/nim-lang/Nim/compare/v1.6.12...v1.6.14
- removed patch nim-fix-tests-certificate-key-too-small.patch as no longer needed
* Mon Mar 13 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.6.12:
  * Fixed “sizeof object containing a set is wrong”
  * Fixed “Missing bounds check for len(toOpenArray..)”
  * Fixed “Add warning for bare except: clause”
  * Fixed “Little Copyright notice inconsistency”
  * Fixed “std/deques: wrong result after calling shrink”
  * Fixed “io.readLine adds ‘\00’ char to the end”
  * Fixed “New JS mdoe issue: return + ref ints.”
  * Fixed “Bad codegen for passed var seq to proc returning array[] converted to seq with @”
  * Fixed “Templates allowed to use ambiguous identifier”
  * Fixed “Mutating a var parameter through a mutable view triggers SIGSEGV”
  * Fixed “gcc error when constructing an object that has the same name in the same file name in 2 different directories”
* Wed Nov 23 2022 David Anes <david.anes@suse.com>
- Update to version 1.6.10:
  * Fixed “–styleCheck:off does not work (and –styleCheck:hint is
    now the default?)”
  * Fixed “dereferencing pointer to incomplete type error with gcc
    9.4 with statics/cast”
  * Fixed “strutils.find uses cstring optimization that stops after
    \0”
  * Fixed “Nimpretty mangles numeric literal procs”
  * Fixed “Regression in proc symbol resolution; Error: attempting
    to call routine “
  * Fixed “of operator doesn’t consider generics under orc/arc”
  * Fixed ““incompatible type” when mixing float32 and cfloat in
    generics”
  * Fixed “cannot generate code for: mSlice with toOpenArray”
  * Fixed “-mm flag is ignored on latest Nim 1.7.1 be4bd8”
  * Full list of changes:
    https://github.com/nim-lang/Nim/compare/v1.6.8...v1.6.10
* Wed Sep 28 2022 David Anes <david.anes@suse.com>
- Remove patch nim-fix-gcc-major-version-detection.patch as it is
  already included upstream.
- Add PCRE dependency as recommended, but required while building.
- Disable broken tests
  * tasyncssl.nim [i586, armv7l]
- Update to version 1.6.8:
  * Fixed “Add –gc:arc (or –mm:arc) induce different behavior when
    using converter”
  * Fixed “Converting unsigned integer to float fails in VM"
  * Fixed “regression(0.20.0 => devel): var params assignment gives
    silently wrong results in VM”
  * Fixed “genDepend broken for duplicate module names in separate
    folders”
  * Fixed “Orc booting compiler doesn’t work with newSeq operations”
  * Fixed “hasCustomPragma and getCustomPragmaVal don’t work on
    fields with backticks”
  * Fixed “Cant use uint64 in case”
  * Fixed “nim jsondoc output is broken”
  * Fixed “Underscores are unnecessarily escaped in db_mysql”
  * Fixed “Invalid codegen when block ends with lent”
  * Fixed “locals doesn’t work with ORC”
  * Fixed “reset does not work on set”
  * Fixed “selectRead and selectWrite are dangerous to use sockets
    with FD numbers bigger than FD_SETSIZE (1024) on *nixes”
  * Fixed “use-after-free bugs in object variants”
  * Fixed “[ARC] C compiler error when using the result of a
    template in the subscript operator”
  * Fixed “Calling nullary templates without () doesn’t work inside
    calls inside other templates”
  * Fixed “[Regression] Incorrect captures of pegs \ident macro in
    nim 1.6”
  * Fixed “Windows gcc shipped with choosenim 1.6.4 with TLS
    emulation turned off : The application was unable to start
    correctly (0xc000007b).”
* Mon Aug  8 2022 David Anes <david.anes@suse.com>
- Disable some tests for some platforms:
  * SFML tests/buildrequires are removed to simplify having the same
    version in all repositories (SLE, backports, etc.).
  * Disable test "tests/arc/tasyncorc.nim", which is failing in
    ppc64le (backports).
- Require/recommend NodeJS 12 only where it is provided, so the
  package is buildable on more codestreams.
* Thu Jul 14 2022 David Anes <david.anes@suse.com>
- Remove duplicated strip for nimble.
- Require (at least) a C compiler.
- Addded _constraints file to require more RAM on build nodes.
- Add patch to correctly detect GCC version, so it builds in i586
  and arm:
  * nim-fix-gcc-major-version-detection.patch
* Wed May  4 2022 David Anes <david.anes@suse.com>
- Reworked whole package.
- Includes upstream fixes for:
  * (bsc#1175333, CVE-2020-15693) httpClient is vulnerable to a
    CR-LF injection
  * (bsc#1175334, CVE-2020-15692) mishandle of argument to
    browsers.openDefaultBrowser
  * (bsc#1175332, CVE-2020-15694) httpClient.get().contentLength()
    fails to properly validate the server response
  * (bsc#1192712, CVE-2021-41259) null byte accepted in getContent
    function, leading to URI validation bypass
  * (bsc#1185948, CVE-2021-29495) stdlib httpClient does not
    validate peer certificates by default
  * (bsc#1185085, CVE-2021-21374) Improper verification of the
    SSL/TLS certificate
  * (bsc#1185084, CVE-2021-21373) "nimble refresh" falls back to a
    non-TLS URL in case of error
  * (bsc#1185083, CVE-2021-21372) doCmd can be leveraged to execute
    arbitrary commands
  * (bsc#1181705, CVE-2020-15690) Standard library asyncftpclient
    lacks a check for newline character
- Add patches:
  * nim-fix-tests-certificate-key-too-small.patch
  * nim-fix-tests-ip-protocol-missing.patch
  * nim-nim-gdb_fix_interpreter.patch
- Following nim tools now work as expected:
  * nim_dbg is now installed.
  * nim-gdb can be successfully launched as it finds and loads
    nim-gdb.py correctly under gdb.
  * nimble package manager stores package information per user.
  * compiler package can be found and used, as it may be required
    by other packages.
- Update to 1.6.6
  * standard library use consistent styles for variable names so it
    can be used in projects which force a consistent style with
  - -styleCheck:usages option.
  * ARC/ORC are now considerably faster at method dispatching,
    bringing its performance back on the level of the refc memory
    management.
  * Full changelog:
    https://nim-lang.org/blog/2022/05/05/version-166-released.html
- Previous updates and changelogs:
  * 1.6.4:
    https://nim-lang.org/blog/2022/02/08/version-164-released.html
  * 1.6.2:
    https://nim-lang.org/blog/2021/12/17/version-162-released.html
  * 1.6.0:
    https://nim-lang.org/blog/2021/10/19/version-160-released.html
  * 1.4.8:
    https://nim-lang.org/blog/2021/05/25/version-148-released.html
  * 1.4.6:
    https://nim-lang.org/blog/2021/04/15/versions-146-and-1212-released.html
  * 1.4.4:
    https://nim-lang.org/blog/2021/02/23/versions-144-and-1210-released.html
  * 1.4.2:
    https://nim-lang.org/blog/2020/12/01/version-142-released.html
  * 1.4.0:
    https://nim-lang.org/blog/2020/10/16/version-140-released.html
* Sat Feb  5 2022 Dirk Müller <dmueller@suse.com>
- update to 1.2.16
  * oids: switch from PRNG to random module
  * nimc.rst: fix table markup
  * nimRawSetjmp: support Windows
  * correctly enable chronos
  * bigints are not supposed to work on 1.2.x
  * disable nimpy
  * misc bugfixes
  * fixes a 'mixin' statement handling regression [backport:1.2
* Wed Apr 21 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.2.12
  * Fixed GC crash resulting from inlining of the memory
    allocation procs
  * Fixed “incorrect raises effect for $(NimNode)” (#17454)
- from version 1.2.10
  * Fixed “JS backend doesn’t handle float->int type conversion “ (#8404)
  * Fixed “The “try except” not work when the “OSError:
    Too many open files” error occurs!” (#15925)
  * Fixed “Nim emits #line 0 C preprocessor directives with
    –debugger:native, with ICE in gcc-10” (#15942)
  * Fixed “tfuturevar fails when activated” (#9695)
  * Fixed “nre.escapeRe is not gcsafe” (#16103)
  * Fixed ““Error: internal error: genRecordFieldAux” - in
    the “version-1-4” branch” (#16069)
  * Fixed “-d:fulldebug switch does not compile with gc:arc” (#16214)
  * Fixed “osLastError may randomly raise defect and crash” (#16359)
  * Fixed “generic importc proc’s don’t work (breaking lots
    of vmops procs for js)” (#16428)
  * Fixed “Concept: codegen ignores parameter passing” (#16897)
  * Fixed “{.push exportc.} interacts with anonymous functions” (#16967)
  * Fixed “memory allocation during {.global.} init breaks GC” (#17085)
  * Fixed "Nimble arbitrary code execution for specially crafted package metadata"
    + https://github.com/nim-lang/security/security/advisories/GHSA-rg9f-w24h-962p
    + (bsc#1185083, CVE-2021-21372)
  * Fixed "Nimble falls back to insecure http url when fetching packages"
    + https://github.com/nim-lang/security/security/advisories/GHSA-8w52-r35x-rgp8
    + (bsc#1185084, CVE-2021-21373)
  * Fixed "Nimble fails to validate certificates due to insecure httpClient defaults"
    + https://github.com/nim-lang/security/security/advisories/GHSA-c2wm-v66h-xhxx
    + (bsc#1185085, CVE-2021-21374)
- from version 1.2.8
  * Fixed “Defer and –gc:arc” (#15071)
  * Fixed “Issue with –gc:arc at compile time” (#15129)
  * Fixed “Nil check on each field fails in generic function” (#15101)
  * Fixed “[strscans] scanf doesn’t match a single character with
    $+ if it’s the end of the string” (#15064)
  * Fixed “Crash and incorrect return values when using
    readPasswordFromStdin on Windows.” (#15207)
  * Fixed “Inconsistent unsigned -> signed RangeDefect usage
    across integer sizes” (#15210)
  * Fixed “toHex results in RangeDefect exception when
    used with large uint64” (#15257)
  * Fixed “Mixing ‘return’ with expressions is allowed in 1.2” (#15280)
  * Fixed “proc execCmdEx doesn’t work with -d:useWinAnsi” (#14203)
  * Fixed “memory corruption in tmarshall.nim” (#9754)
  * Fixed “Wrong number of variables” (#15360)
  * Fixed “defer doesnt work with block, break and await” (#15243)
  * Fixed “Sizeof of case object is incorrect. Showstopper” (#15516)
  * Fixed “Mixing ‘return’ with expressions is allowed in 1.2” (#15280)
  * Fixed “regression(1.0.2 => 1.0.4) VM register messed up
    depending on unrelated context” (#15704)
- from version 1.2.6
  * Fixed “The pegs module doesn’t work with generics!” (#14718)
  * Fixed “[goto exceptions] {.noReturn.} pragma is not detected
    in a case expression” (#14458)
  * Fixed “[exceptions:goto] C compiler error with dynlib pragma
    calling a proc” (#14240)
  * Fixed “Nim source archive install: ‘install.sh’ fails with error:
    cp: cannot stat ‘bin/nim-gdb’: No such file or directory” (#14748)
  * Fixed “Stropped identifiers don’t work as field names in
    tuple literals” (#14911)
  * Fixed “uri.decodeUrl crashes on incorrectly formatted input” (#14082)
  * Fixed “odbcsql module has some wrong integer types” (#9771)
  * Fixed “[ARC] Compiler crash declaring a finalizer proc
    directly in ‘new’” (#15044)
  * Fixed “code with named arguments in proc of winim/com can
    not been compiled” (#15056)
  * Fixed “javascript backend produces javascript code with syntax
    error in object syntax” (#14534)
  * Fixed “[ARC] SIGSEGV when calling a closure as a tuple
    field in a seq” (#15038)
  * Fixed “Compiler crashes when using string as object variant
    selector with else branch” (#14189)
  * Fixed “Constructing a uint64 range on a 32-bit machine leads
    to incorrect codegen” (#14616)
* Sun Jun 21 2020 dmacvicar@suse.com
- Update to version 1.2.2:
  * See https://nim-lang.org/blog.html for details
- Enable the full testsuite in the %%check section
  * Add build dependencies to run the testsuite
  * Whitelists a few tests that are not passing yet
* Wed Nov 13 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.0.2:
  * See https://nim-lang.org/blog.html for details
- Update dependencies (based on changes by Federico Ceratto
* Mon Jun  3 2019 m.szczepaniak.000@gmail.com
- Added ppc64le
* Mon Jun  3 2019 m.szczepaniak.000@gmail.com
- Added armv7l and aarch64
* Fri May 31 2019 Martin Pluskal <mpluskal@suse.com>
- Force more optflags usage
- Fix location of config files (boo#1137006)
* Tue May 14 2019 m.szczepaniak.000@gmail.com
- Update to version 0.19.6:
  Please see:
  https://nim-lang.org/blog/2019/05/13/version-0196-released.html
* Tue Jan  1 2019 mvetter@suse.com
- Update to version 0.19.2:
  Please see:
  https://nim-lang.org/blog/2018/12/31/version-0192-released.html
* Mon Oct 22 2018 mvetter@suse.com
- Update to version 0.19.0:
  * Please see:
    https://nim-lang.org/blog/2018/09/26/version-0190-released.html
* Fri Mar  2 2018 mvetter@suse.com
- Update to version 0.18.0:
  * Please see:
    https://nim-lang.org/blog/2018/03/01/version-0180-released.html
- Add nim-rpmlintrc
* Fri Jan  5 2018 mpluskal@suse.com
- Update to version 0.17.2:
  * Bugfix release
  * For details see:
    https://nim-lang.org/blog/2017/09/07/version-0172-released.html
* Sat Jun  3 2017 mpluskal@suse.com
- Update to version 0.17.0:
  * https://nim-lang.org/blog/2017/05/17/version-0170-released.html
* Sat Mar 11 2017 mpluskal@suse.com
- Update list of files to fix building on Factory
* Thu Mar  2 2017 jengelh@inai.de
- Update description
* Sun Feb 19 2017 sor.alexei@meowr.ru
- Update to version 0.16.0:
  * No changelog available.
- Build and install libraries, etc.
- Install configuration files.
- Recommend git for nimble.
* Fri Dec 23 2016 mpluskal@suse.com
- Cleanup package to follow packaging guidelines
* Fri Dec 23 2016 thomazi@linux.com
- Fixing spec summary
